@@ -44,9 +44,7 @@ def service(data, secrets):
     """
     try:
         initialization(secrets)
-        logging.debug(f"Predict {data=}")
         y = predict(data, init_object, secrets)
-        logging.debug(f"Prediction is {y=}")
         return dict(status="ok", prediction=y, model_id=c.model_id)
     except ModelException as error:
         error_message = f"Could not get a prediction. Message: {error}"
